pkgname <- "pairwise"
source(file.path(R.home("share"), "R", "examples-header.R"))
options(warn = 1)
library('pairwise')

base::assign(".oldSearch", base::search(), pos = 'CheckExEnv')
cleanEx()
nameEx("DEU_PISA2012")
### * DEU_PISA2012

flush(stderr()); flush(stdout())

### Name: DEU_PISA2012
### Title: Data from PISA 2012 - German Sample
### Aliases: DEU_PISA2012
### Keywords: datasets

### ** Examples

##############################################################
data(DEU_PISA2012)
str(DEU_PISA2012)



cleanEx()
nameEx("Neoffi5")
### * Neoffi5

flush(stderr()); flush(stdout())

### Name: Neoffi5
### Title: Polytomous example data in Rost 2004
### Aliases: Neoffi5
### Keywords: datasets

### ** Examples

data(Neoffi5)
dim(Neoffi5)
###########
# frequencies
ftab(Neoffi5)
# Itemparameter to be compared with Rost (2004), page 211.
summary(pair(Neoffi5)) 
# Itemparameter to be compared with Rost (2004), page 213.
summary(pers(pair(Neoffi5))) 



cleanEx()
nameEx("bfiN")
### * bfiN

flush(stderr()); flush(stdout())

### Name: bfiN
### Title: 5 polytomous personality items
### Aliases: bfiN
### Keywords: datasets

### ** Examples

data(bfiN)
dim(bfiN)
##############################################################
names(bfiN) # show all variable names of data.frame bfiN
range(bfiN,na.rm=TRUE) # checking the valid response range




cleanEx()
nameEx("bfiN_miss")
### * bfiN_miss

flush(stderr()); flush(stdout())

### Name: bfiN_miss
### Title: 5 polytomous personality items
### Aliases: bfiN_miss
### Keywords: datasets

### ** Examples

data(bfiN_miss)
dim(bfiN_miss)
##############################################################
names(bfiN_miss) # show all variable names of data.frame bfiN_miss
range(bfiN_miss,na.rm=TRUE) # checking the valid response range
colSums(is.na(bfiN_miss))/dim(bfiN_miss)[1] # percentage of missing per variable



cleanEx()
nameEx("catprob")
### * catprob

flush(stderr()); flush(stdout())

### Name: catprob
### Title: Category Probability Plots
### Aliases: catprob

### ** Examples

########
data(sim200x3)
result <- pair(sim200x3)
catprob(pair_obj = result, itemnumber = 2 )
data(bfiN)
result <- pair(bfiN)
catprob(pair_obj = result, itemnumber = 3 )



cleanEx()
nameEx("cog")
### * cog

flush(stderr()); flush(stdout())

### Name: cog
### Title: Math PISA (2003) data
### Aliases: cog
### Keywords: datasets

### ** Examples

data(cog)
dim(cog)
##############################################################
names(cog) # show all variable names of data.frame cog
names(cog[,4:34]) # show the variable names of the math items
names(cog[,1:3]) # show the variable names of the ID variables




cleanEx()
nameEx("cogBOOKLET")
### * cogBOOKLET

flush(stderr()); flush(stdout())

### Name: cogBOOKLET
### Title: Booklet allocation table for Math PISA (2003) data
### Aliases: cogBOOKLET
### Keywords: datasets

### ** Examples

data(cogBOOKLET)
cogBOOKLET



cleanEx()
nameEx("esc")
### * esc

flush(stderr()); flush(stdout())

### Name: esc
### Title: Expected Score Curves Plots
### Aliases: esc

### ** Examples

########
data(bfiN)
result <- pers(pair(bfiN))
esc(pers_obj=result,1,lwd=2) # plot for first item
esc(pers_obj=result,2,lwd=2) # plot for second item
for(i in 1:5){esc(pers_obj=result,i,lwd=2)}
#########
esc(pers_obj=result,2,integ="all",lwd=2) # plot for secod item



cleanEx()
nameEx("ftab")
### * ftab

flush(stderr()); flush(stdout())

### Name: ftab
### Title: Tabulating Answer Categories in Data
### Aliases: ftab

### ** Examples

########
data(bfiN)
ftab(bfiN)
data(sim200x3)
ftab(sim200x3)



cleanEx()
nameEx("gif")
### * gif

flush(stderr()); flush(stdout())

### Name: gif
### Title: Graphical Item Fit Plots
### Aliases: gif

### ** Examples

########
data(bfiN)
pers_obj <- pers(pair(bfiN))
#### plot empirical category probabilities
gif(pers_obj = pers_obj, itemnumber = 1 )
gif(pers_obj = pers_obj, itemnumber = 1 , integ=8) # integration over 8 points
gif(pers_obj = pers_obj, itemnumber = 1 , integ=8, kat=1) # only for category number 1



cleanEx()
nameEx("grm")
### * grm

flush(stderr()); flush(stdout())

### Name: grm
### Title: Graphical Model Check
### Aliases: grm

### ** Examples

data(bfiN) # loading example data set

# calculating itemparameters and SE for two random allocated subsamples
grm_med<-grm(daten=bfiN, split = "median")
summary(grm_med)
plot(grm_med)

grm_ran<-grm(daten=bfiN, split = "random")

summary(grm_ran)

# some examples for plotting options
# plotting item difficulties for two subsamples against each other
# with elipses for a CI = 95% .
plot(grm_ran)

# using triangles as plotting pattern
plot(grm_ran,pch=2)

#plotting without CI ellipses
plot(grm_ran,ci=0,pch=2)

# plotting with item names
plot(grm_ran,itemNames=TRUE)

# Changing the size of the item names
plot(grm_ran,itemNames=TRUE, cex.names = 1.3)

# Changing the color of the CI ellipses
plot(grm_ran,itemNames=TRUE, cex.names = .8, col.error="green")

###### example from details section 'Some Notes on Standard Errors' ########
grm_def<-grm(daten=bfiN, split = "random",splitseed=13)
plot(grm_def)
######
grm_400<-grm(daten=bfiN, split = "random", splitseed=13 ,nsample=400)
plot(grm_400)



cleanEx()
nameEx("iff")
### * iff

flush(stderr()); flush(stdout())

### Name: iff
### Title: Item information function
### Aliases: iff

### ** Examples

########
data(sim200x3)
result <- pair(sim200x3)
# IFF plot for Item No. 2
iff(pair_obj = result, itemnumber = 2 )
# IFF plot for Categories of Item No. 2
iff(pair_obj = result, itemnumber = 2 ,cat=TRUE)
# IFF at theta=0 for Item No. 2
iff(pair_obj = result, itemnumber = 2 ,x=0)
# IFF at theta=0 for Categories of Item No. 2
iff(pair_obj = result, itemnumber = 2 ,x=0,cat=TRUE)
# IFF of Item No. 2 for a given range of thetas
iff(pair_obj = result, itemnumber = 2 ,x=seq(0,4,.1))
# ... etc.
iff(pair_obj = result, itemnumber = 2 ,x=seq(0,4,.1),cat=TRUE)
##### examples with other data ...
data(bfiN)
result <- pair(bfiN)
iff(pair_obj = result, itemnumber = 3 )
iff(pair_obj = result, itemnumber = 3 ,cat=TRUE)



cleanEx()
nameEx("kft5")
### * kft5

flush(stderr()); flush(stdout())

### Name: kft5
### Title: Dichotomous example data in Rost 2004
### Aliases: kft5
### Keywords: datasets

### ** Examples

data(kft5)
dim(kft5)
###########
# frequencies
ftab(kft5)
# Itemparameter to be compared with Rost (2004), page 120.
summary(pair(kft5)) 
# Itemparameter to be compared with Rost (2004), page 120.
summary(pers(pair(kft5))) 



cleanEx()
nameEx("make.incidenz")
### * make.incidenz

flush(stderr()); flush(stdout())

### Name: make.incidenz
### Title: Converting a booklet allocation table into a incidence matrix
### Aliases: make.incidenz

### ** Examples

#########################
data(cog);data(cogBOOKLET) # loading reponse and allocation data
table(cog$BOOKID)# show n persons per booklet
names(table(c(as.matrix(cogBOOKLET[,2:5])))) # show booklets in allocation data
d<-(cog[cog$BOOKID!=14,]) # skip persons which got booklet No.14.
inc<-make.incidenz(tab=cogBOOKLET, bookid=d$BOOKID) # make just the incidence matrix
inc
make.incidenz(tab=cogBOOKLET, bookid=d$BOOKID, info=TRUE) # get some info too
# in this case not necessary but just to show
# using the (item) names in cog to secure the item order in incidence matrix:
make.incidenz(tab=cogBOOKLET, bookid=d$BOOKID, item_order=names(cog)[4:34])
#######################



cleanEx()
nameEx("pair")
### * pair

flush(stderr()); flush(stdout())

### Name: pair
### Title: Rasch Item Parameter (Main Function)
### Aliases: pair

### ** Examples

data(bfiN) # loading example data set
# calculating itemparameters for 5 neuroticism items with 6 answer categories (0-5).
neuro_itempar<-pair(daten = bfiN, m = 6)
summary(neuro_itempar)
summary(neuro_itempar, sortdif=TRUE) # ordered by difficulty
# plotting threshold profiles for 5 neuroticism items.
plot(neuro_itempar)
plot(neuro_itempar, sortdif=TRUE) # plotting ordered by difficulty
################ with unequal number of categories
data(sim200x3)
res<-pair(sim200x3)
summary(res)
plot(res)



cleanEx()
nameEx("pairSE")
### * pairSE

flush(stderr()); flush(stdout())

### Name: pairSE
### Title: Item Parameter calculation with Standard Errors for polytomous
###   Partial Credit Model
### Aliases: pairSE

### ** Examples

data(bfiN) # loading example data set

# calculating itemparameters and their SE for 5 neuroticism items with 6 answer categories (0-5).
neuro_itempar<-pairSE(daten = bfiN, m = 6)
summary(neuro_itempar) # summary for result

# plotting item thresholds with with their CI = 95%
plot(neuro_itempar)
plot(neuro_itempar,sortdif=TRUE)

###### example from details section 'Some Notes on Standard Errors' ########
neuro_itempar_400<-pairSE(daten = bfiN, m = 6,nsample=400)
plot(neuro_itempar)
plot(neuro_itempar_400)



cleanEx()
nameEx("pairwise.item.fit")
### * pairwise.item.fit

flush(stderr()); flush(stdout())

### Name: pairwise.item.fit
### Title: Item Fit Indices
### Aliases: pairwise.item.fit

### ** Examples

########
data(sim200x3)
result <- pers(pair(sim200x3))
pairwise.item.fit(pers_obj=result) # item fit statistic



cleanEx()
nameEx("pairwise.person.fit")
### * pairwise.person.fit

flush(stderr()); flush(stdout())

### Name: pairwise.person.fit
### Title: Person Fit Indices
### Aliases: pairwise.person.fit

### ** Examples

########
data(sim200x3)
result <- pers(pair(sim200x3))
pairwise.person.fit(pers_obj=result) # item fit statistic



cleanEx()
nameEx("pers")
### * pers

flush(stderr()); flush(stdout())

### Name: pers
### Title: WLE - Rasch Person Parameter
### Aliases: pers

### ** Examples

############
data(sim200x3)
result <- pers(itempar=pair(sim200x3))
summary(result)
plot(result)
logLik(result) # Log-Likelihood for 'estimated' model
logLik(result, sat=TRUE) # Log-Likelihood for saturated model
AIC(logLik(result)) # AIC for 'estimated' model
AIC(logLik(result, sat=TRUE)) # AIC for saturated model
BIC(logLik(result)) # BIC for 'estimated' model
BIC(logLik(result, sat=TRUE)) # BIC for saturated model
###### following example requires package eRm ######
# require(eRm)
# # itemparameter with eRm:
# itempar_eRm <- thresholds(PCM(sim200x3))$ threshtable[[1]][,2:3]
# # pairwise personparameter with eRm-itemparameter and data:
# summary(pers(itempar=itempar_eRm,daten=sim200x3))
# # eRm personparameter:
# person.parameter(PCM(sim200x3))
# # personparameter with pairwise:
# summary(pers(pair(sim200x3)))



cleanEx()
nameEx("ptbis")
### * ptbis

flush(stderr()); flush(stdout())

### Name: ptbis
### Title: Point Biserial Correlations
### Aliases: ptbis

### ** Examples

######################
########
data(sim200x3) # loading reponse data
y <- rowSums(sim200x3)
ptbis(y=y, daten=sim200x3)
####
result <- pers(pair(sim200x3))
ptbis(y= result)



cleanEx()
nameEx("rfa")
### * rfa

flush(stderr()); flush(stdout())

### Name: rfa
### Title: Rasch Residual Factor Analysis
### Aliases: rfa

### ** Examples

######################
########
data(bfiN) # loading reponse data
pers_obj <- pers(pair(bfiN))
result <- rfa(pers_obj)
summary(result)
plot(result)
####



cleanEx()
nameEx("sim200x3")
### * sim200x3

flush(stderr()); flush(stdout())

### Name: sim200x3
### Title: Simulated Data
### Aliases: sim200x3
### Keywords: datasets

### ** Examples

data(sim200x3)
dim(sim200x3)
##############################################################
apply(sim200x3,2,table)



cleanEx()
nameEx("tff")
### * tff

flush(stderr()); flush(stdout())

### Name: tff
### Title: Test information function
### Aliases: tff

### ** Examples

########
data(sim200x3)
result <- pair(sim200x3)
tff(pair_obj = result) # TIF plot
tff(pair_obj = result, cat=TRUE) # TIF plot
tff(pair_obj = result, items=c("V1","V3"), cat=TRUE) # TIF plot
tff(pair_obj = result, x=0) # TIF at theta=0
tff(pair_obj = result, x=seq(0,4,.1)) # TIF for a given range of Thetas
##### examples with other data ...
data(bfiN)
result <- pair(bfiN)
tff(pair_obj = result)
tff(pair_obj = result, cat=TRUE) # TIF plot



### * <FOOTER>
###
options(digits = 7L)
base::cat("Time elapsed: ", proc.time() - base::get("ptime", pos = 'CheckExEnv'),"\n")
grDevices::dev.off()
###
### Local variables: ***
### mode: outline-minor ***
### outline-regexp: "\\(> \\)?### [*]+" ***
### End: ***
quit('no')
